@@ -14,7 +14,7 @@ Net::Braintree->configuration->environment("integration");
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 use Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw(create_settled_transaction not_ok should_throw simulate_form_post_for_tr make_subscription_past_due);
+our @EXPORT = qw(create_escrowed_transaction create_settled_transaction not_ok should_throw simulate_form_post_for_tr make_subscription_past_due);
 our @EXPORT_OK = qw();
 
 sub not_ok {
@@ -42,6 +42,26 @@ sub create_settled_transaction {
   return Net::Braintree::Result->new(response => $settlement);
 }
 
+sub create_escrowed_transaction {
+  my $sale = Net::Braintree::Transaction->sale({
+    amount => "50.00",
+    merchant_account_id => "sandbox_sub_merchant_account",
+    credit_card => {
+      number => "5431111111111111",
+      expiration_date => "05/12"
+    },
+    service_fee_amount => "10.00",
+    options => {
+      hold_in_escrow => "true"
+    }
+  });
+  my $http       = Net::Braintree::HTTP->new(config => Net::Braintree->configuration);
+  my $settlement = $http->put("/transactions/" . $sale->transaction->id . "/settle");
+  my $escrow     = $http->put("/transactions/" . $sale->transaction->id . "/escrow");
+  
+  return Net::Braintree::Result->new(response => $escrow);
+}
+
 sub simulate_form_post_for_tr {
   my ($tr_string, $form_params) = @_;
   my $escaped_tr_string = CGI::escape($tr_string);
